@@ -1,9 +1,10 @@
+from functools import lru_cache
+
 from django import template
 from django.conf import settings
 from django.forms.formsets import BaseFormSet
 from django.template.loader import get_template
 
-from crispy_forms.compatibility import lru_cache
 from crispy_forms.helper import FormHelper
 from crispy_forms.utils import TEMPLATE_PACK, get_template_pack
 
@@ -62,10 +63,7 @@ class BasicNode(template.Node):
 
     def __init__(self, form, helper, template_pack=None):
         self.form = form
-        if helper is not None:
-            self.helper = helper
-        else:
-            self.helper = None
+        self.helper = helper
         self.template_pack = template_pack or get_template_pack()
 
     def get_render(self, context):
@@ -157,7 +155,6 @@ class BasicNode(template.Node):
             "%s_class" % form_type: attrs["attrs"].get("class", ""),
             "%s_id" % form_type: attrs["attrs"].get("id", ""),
             "%s_method" % form_type: attrs.get("form_method", "post"),
-            "%s_style" % form_type: attrs.get("form_style", None),
             "%s_tag" % form_type: attrs.get("form_tag", True),
             "disable_csrf": attrs.get("disable_csrf", False),
             "error_text_inline": attrs.get("error_text_inline", True),
@@ -169,7 +166,6 @@ class BasicNode(template.Node):
             "form_show_labels": attrs.get("form_show_labels", True),
             "formset_error_title": attrs.get("formset_error_title", None),
             "help_text_inline": attrs.get("help_text_inline", False),
-            "html5_required": attrs.get("html5_required", False),
             "include_media": attrs.get("include_media", True),
             "inputs": attrs.get("inputs", []),
             "is_formset": is_formset,
@@ -235,21 +231,21 @@ def do_uni_form(parser, token):
         {% crispy form %}
         {% crispy form 'bootstrap' %}
     """
-    token = token.split_contents()
-    form = token.pop(1)
+    tokens = token.split_contents()
+    form = tokens.pop(1)
 
     helper = None
     template_pack = "'%s'" % get_template_pack()
 
     # {% crispy form helper %}
     try:
-        helper = token.pop(1)
+        helper = tokens.pop(1)
     except IndexError:
         pass
 
     # {% crispy form helper 'bootstrap' %}
     try:
-        template_pack = token.pop(1)
+        template_pack = tokens.pop(1)
     except IndexError:
         pass
 
@@ -261,7 +257,7 @@ def do_uni_form(parser, token):
     if template_pack is not None:
         template_pack = template_pack[1:-1]
         ALLOWED_TEMPLATE_PACKS = getattr(
-            settings, "CRISPY_ALLOWED_TEMPLATE_PACKS", ("bootstrap", "uni_form", "bootstrap3", "bootstrap4")
+            settings, "CRISPY_ALLOWED_TEMPLATE_PACKS", ("uni_form", "bootstrap3", "bootstrap4")
         )
         if template_pack not in ALLOWED_TEMPLATE_PACKS:
             raise template.TemplateSyntaxError(
